Function for optimizations of "lineqGP" S3 class objects.
lineqGPOptim(
model,
x0 = model$kernParam$par,
eval_f = "logLik",
lb = rep(0.01, length(x0)),
ub = rep(Inf, length(x0)),
opts = list(algorithm = "NLOPT_LD_MMA", print_level = 0, ftol_abs = 0.001, maxeval =
50, check_derivatives = FALSE, parfixed = rep(FALSE, length(x0))),
seed = 1,
estim.varnoise = FALSE,
bounds.varnoise = c(0, Inf),
add.constr = FALSE,
additive = FALSE,
mcmc.opts = list(probe = "Genz", nb.mcmc = 1000),
max.trials = 10,
...
)a list with the structure of the constrained Kriging model.
the initial values for the parameters to be optimized over.
a function to be minimized, with first argument the vector of parameters over which minimization is to take place. It should return a scalar result.
a vector with lower bounds of the params. The params are forced to be positive.
See nloptr.
a vector with upper bounds of the params. See nloptr.
see nl.opts. Parameter parfixed indices of
fixed parameters to do not be optimised. If estim.varnoise is true, the
noise variance is estimated.
an optional number. Set a seed to replicate results.
an optional logical. If TRUE, a noise variance is estimated.
a vector with bounds of noise variance.
an optional logical. If TRUE, the inequality constraints are taken
into account in the optimisation.
an optional logical. If TRUE, the likelihood of an additive GP model
is computed in the optimisation.
if add.constr, mcmc options passed to methods.
the value of the maximum number of trials when errors are produced by instabilities.
further arguments passed to or from other methods.
An optimized lineqGP model.
This function has to be improved in the future for more stable procedures. Cros-validation (CV) methods could be implemented in future versions.