Learn R Programming

lineqGPR (version 0.1.1)

tmvrnorm: Sampling Methods of Truncated Multivariate Normal Distributions

Description

Wrapper function with a collection of Monte Carlo and Markov Chain Monte Carlo samplers for truncated multivariate normal distributions. The function invokes particular samplers which depend on the class of the first argument.

Usage

tmvrnorm(object, nsim, ...)

Arguments

object

an object with: mu (mean vector), Sigma (covariance matrix), lb (lower bound vector), ub (upper bound vector).

nsim

an integer corresponding to the number of simulations.

...

further arguments passed to or from other methods.

Value

A matrix with the sample path. Samples are indexed by columns.

See Also

tmvrnorm.RSM, tmvrnorm.HMC, tmvrnorm.ExpT