Wrapper function with a collection of Monte Carlo and Markov Chain Monte Carlo samplers for truncated multivariate normal distributions. The function invokes particular samplers which depend on the class of the first argument.
tmvrnorm(object, nsim, ...)an object with:
mu (mean vector), Sigma (covariance matrix),
lb (lower bound vector), ub (upper bound vector).
an integer corresponding to the number of simulations.
further arguments passed to or from other methods.
A matrix with the sample path. Samples are indexed by columns.